# CHANGELOG



## v0.50.2 (2024-07-29)

### Chore

* chore: update from copier template (#280) ([`7482582`](https://github.com/MartinBernstorff/lumberman/commit/748258230acb5648b4bcbbee22fabfaa05028783))

* chore: update from copier template ([`c626f65`](https://github.com/MartinBernstorff/lumberman/commit/c626f6524452bfa30fd7b072cac7870b4cc51036))

### Fix

* fix: release package (#281) ([`30aeb70`](https://github.com/MartinBernstorff/lumberman/commit/30aeb70d919ae0e78b013c058303e69903b8bf1b))

* fix: release package ([`84755b9`](https://github.com/MartinBernstorff/lumberman/commit/84755b95112fb3fd4be7e01fee76ac63fdaf4b03))

* fix: handle repos with no issues (#279) ([`b374dca`](https://github.com/MartinBernstorff/lumberman/commit/b374dcaa52776ce986d7c8e9eb6eeda612394305))

* fix: handle repos with no issues ([`f866bb1`](https://github.com/MartinBernstorff/lumberman/commit/f866bb1bf992420bd2a5802aa05fe5d72a83c735))

### Unknown

* deps:(deps): bump typer from 0.12.1 to 0.12.3 (#278) ([`37f517d`](https://github.com/MartinBernstorff/lumberman/commit/37f517d8f42b3436b2a29865f514e554298b5102))

* deps:(deps): bump typer from 0.12.1 to 0.12.3

Bumps [typer](https://github.com/tiangolo/typer) from 0.12.1 to 0.12.3.
- [Release notes](https://github.com/tiangolo/typer/releases)
- [Changelog](https://github.com/tiangolo/typer/blob/master/docs/release-notes.md)
- [Commits](https://github.com/tiangolo/typer/compare/0.12.1...0.12.3)

---
updated-dependencies:
- dependency-name: typer
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`1fa46e4`](https://github.com/MartinBernstorff/lumberman/commit/1fa46e4a1c200099f5ea036df6da6a303b14d94b))

* deps:(deps-dev): bump typer from 0.12.0 to 0.12.1 (#277) ([`c17201b`](https://github.com/MartinBernstorff/lumberman/commit/c17201ba7c177855de3e254f16baf645e9c9d30f))

* deps:(deps-dev): bump typer from 0.12.0 to 0.12.1

Bumps [typer](https://github.com/tiangolo/typer) from 0.12.0 to 0.12.1.
- [Release notes](https://github.com/tiangolo/typer/releases)
- [Changelog](https://github.com/tiangolo/typer/blob/master/docs/release-notes.md)
- [Commits](https://github.com/tiangolo/typer/compare/0.12.0...0.12.1)

---
updated-dependencies:
- dependency-name: typer
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`af0df24`](https://github.com/MartinBernstorff/lumberman/commit/af0df24be159de11a5736e09c46b4ae9371796ad))

* deps:(deps-dev): bump typer from 0.9.0 to 0.12.0 (#276) ([`7efcd48`](https://github.com/MartinBernstorff/lumberman/commit/7efcd482148dc6ef1c0ee7454b00097c7be4cb94))

* deps:(deps-dev): bump typer from 0.9.0 to 0.12.0

Bumps [typer](https://github.com/tiangolo/typer) from 0.9.0 to 0.12.0.
- [Release notes](https://github.com/tiangolo/typer/releases)
- [Changelog](https://github.com/tiangolo/typer/blob/master/docs/release-notes.md)
- [Commits](https://github.com/tiangolo/typer/compare/0.9.0...0.12.0)

---
updated-dependencies:
- dependency-name: typer
  dependency-type: direct:production
  update-type: version-update:semver-minor
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`98f70c5`](https://github.com/MartinBernstorff/lumberman/commit/98f70c5fa2fd74cfdff1230ee2c2c42f1c2b0f3d))

* deps:(deps-dev): bump rich from 13.7.0 to 13.7.1 (#274) ([`d53fb45`](https://github.com/MartinBernstorff/lumberman/commit/d53fb450c688c3925563a78f2242fad7d080e7b4))

* deps:(deps-dev): bump rich from 13.7.0 to 13.7.1

Bumps [rich](https://github.com/Textualize/rich) from 13.7.0 to 13.7.1.
- [Release notes](https://github.com/Textualize/rich/releases)
- [Changelog](https://github.com/Textualize/rich/blob/master/CHANGELOG.md)
- [Commits](https://github.com/Textualize/rich/compare/v13.7.0...v13.7.1)

---
updated-dependencies:
- dependency-name: rich
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`6b09454`](https://github.com/MartinBernstorff/lumberman/commit/6b09454832159461c46f1308e47d4613e5d0ed6c))


## v0.50.1 (2024-02-29)

### Fix

* fix(#272): correct branch naming (#273) ([`02662eb`](https://github.com/MartinBernstorff/lumberman/commit/02662eb9c14a1e6b1166c14fc7ddc3e963fe59f2))

* fix(#272): correct branch naming

Fixes #272 ([`540309a`](https://github.com/MartinBernstorff/lumberman/commit/540309a9bd07832d504d4551591825e52c9a59f3))

### Refactor

* refactor: separate `GithubIssue` and `ManualIssue` #269 (#271) ([`9d10ea7`](https://github.com/MartinBernstorff/lumberman/commit/9d10ea7f20b6e00e491179c4496df44636ab9ff5))

### Unknown

* separate GithubIssue and ManualIssue #269 ([`987e79b`](https://github.com/MartinBernstorff/lumberman/commit/987e79b56de65c9f4015c218a5975b5232fe8413))


## v0.50.0 (2024-02-29)

### Feature

* feat: exact matching (#270) ([`0317ce2`](https://github.com/MartinBernstorff/lumberman/commit/0317ce257b20dcde1d4dc92a88f3f0198765a7e0))

* feat: exact matching ([`1fb36c2`](https://github.com/MartinBernstorff/lumberman/commit/1fb36c20059768cd7da2d022aecc3ac10ebb37b5))

### Refactor

* refactor: move issue processing logic onto issue itself (#268) ([`af6eb92`](https://github.com/MartinBernstorff/lumberman/commit/af6eb922d51c07a006392015fc5cf60fac37db33))

* refactor: move issue processing logic onto issue itself ([`f86d97e`](https://github.com/MartinBernstorff/lumberman/commit/f86d97e47f72e8c5936a82e08695311738858138))


## v0.49.0 (2024-02-28)

### Feature

* feat(#257): print entire issue thread (#267)

Fixes #257 ([`848481d`](https://github.com/MartinBernstorff/lumberman/commit/848481dad9f711f949f787dd94c25174d2998ef7))

* feat(#257): print entire issue thread

Fixes #257 ([`bde62c0`](https://github.com/MartinBernstorff/lumberman/commit/bde62c08aef159c6a54c39a2fd990233f1ba7482))


## v0.48.0 (2024-02-28)

### Feature

* feat(#253): allow manual creation directly in fzf (#264)

Fixes #253 ([`732e955`](https://github.com/MartinBernstorff/lumberman/commit/732e95562cdb78867e797d14d785f9e988e265df))

* feat(#253): allow manual creation directly in fzf

Fixes #253 ([`505a0d8`](https://github.com/MartinBernstorff/lumberman/commit/505a0d8f58381d0313f4cfff51384fb307248c74))

### Refactor

* refactor: remove recent and manual prompt (#265) ([`33382a1`](https://github.com/MartinBernstorff/lumberman/commit/33382a124cdfc9f80e616c24ef2d845dcf13c07c))

* refactor: remove recent and manual prompt ([`0a6f458`](https://github.com/MartinBernstorff/lumberman/commit/0a6f458fb6d91c276298cde792322427fe8cdf01))


## v0.47.0 (2024-02-27)

### Feature

* feat(#259): add label on PR

Fixes #259 ([`7218822`](https://github.com/MartinBernstorff/lumberman/commit/7218822149539ed1420f7a673888ed54f73ba636))

### Fix

* fix: directions (#263) ([`ae648ed`](https://github.com/MartinBernstorff/lumberman/commit/ae648ed569e9866ee134e96bfe8aa6749674e9e6))


## v0.46.1 (2024-02-27)

### Fix

* fix(#261): add shorthands for locations (#262)

Fixes #261 ([`13d7446`](https://github.com/MartinBernstorff/lumberman/commit/13d744684125736b8b1fda0b3f1bec8d2f148749))

### Unknown

* bug(#261): shorthand for top not working

Fixes #261 ([`7542490`](https://github.com/MartinBernstorff/lumberman/commit/7542490860d6f6cb62f4dbff337caab92ff3e923))


## v0.46.0 (2024-02-23)

### Feature

* feat(#259): add label on PR (#260)

Fixes #259 ([`85c9429`](https://github.com/MartinBernstorff/lumberman/commit/85c94291d61a00c9a39fbe3db02bb7aba9e9634b))

* feat(#259): add label on PR

Fixes #259 ([`12ae39d`](https://github.com/MartinBernstorff/lumberman/commit/12ae39d62544b0ff07fd86154bcf6b1cdc329ebd))


## v0.45.1 (2024-02-23)

### Fix

* fix(#252): quote every line in issue description when outputting to terminal (#256)

Fixes #252 ([`38d860d`](https://github.com/MartinBernstorff/lumberman/commit/38d860ddbb31537e12bb44d7408878389e131dd8))

* fix(#252): quote every line in issue description when outputting to terminal

Fixes #252 ([`7d91ebb`](https://github.com/MartinBernstorff/lumberman/commit/7d91ebb9d31b5143e4379075e78a6c73760e159f))

### Refactor

* refactor: remove mvc terminology (#248) ([`1b6adf3`](https://github.com/MartinBernstorff/lumberman/commit/1b6adf33e646a793b63b3cf43d05ccf31eb5a500))

### Unknown

* dev: update copier (#254) ([`3e6ce29`](https://github.com/MartinBernstorff/lumberman/commit/3e6ce29df2d8e0f00c1a3028ef6b00a453fa57e1))

* dev: update copier ([`a8b4d16`](https://github.com/MartinBernstorff/lumberman/commit/a8b4d166f1c3d32d7214db1b81d43483bad5478c))

* update .copier-answers.yml and Dockerfile ([`9de3dbb`](https://github.com/MartinBernstorff/lumberman/commit/9de3dbbe670de9c46696d80947f6307cbcd0aeb4))

* dev: update devcontainer (#250) ([`8f18f28`](https://github.com/MartinBernstorff/lumberman/commit/8f18f28aae404624469d4ef75bffd99898e34dbc))

* Update README.md ([`9842102`](https://github.com/MartinBernstorff/lumberman/commit/98421022d5ccd044669f1bd4a4cacfd2be14ad79))

* Update README.md ([`4d48351`](https://github.com/MartinBernstorff/lumberman/commit/4d483519a21d3e66e9d520e592f5dc739bc2587c))

* Update README.md ([`b403718`](https://github.com/MartinBernstorff/lumberman/commit/b403718018893cec096e6bef7e2f3e9a6c01d4c2))

* Update README.md ([`deaf1d6`](https://github.com/MartinBernstorff/lumberman/commit/deaf1d64a0194cb83bf7e485c1abd9ab80e58bd3))

* Update README.md ([`529f594`](https://github.com/MartinBernstorff/lumberman/commit/529f594b65f1d030fa6933a1fdba87b24bd300c4))

* Update README.md ([`1275bc3`](https://github.com/MartinBernstorff/lumberman/commit/1275bc3c026ff927660d78d3184a0c33350a3f59))

* Update README.md ([`35a4b14`](https://github.com/MartinBernstorff/lumberman/commit/35a4b14333ee6824178069eb6cef2b72f94d9ad3))

* dev: migrate to copier (#249) ([`b3e01aa`](https://github.com/MartinBernstorff/lumberman/commit/b3e01aa1497690a27e1de2c219f503a2fd948a44))


## v0.45.0 (2024-02-19)

### Feature

* feat(#235): self-assign on issue selection (#247)

Fixes #235 ([`95fb56c`](https://github.com/MartinBernstorff/lumberman/commit/95fb56cd124f682a72a633d484edc679c9ea707b))

* feat(#235): self-assign on issue selection

Fixes #235 ([`bb4b552`](https://github.com/MartinBernstorff/lumberman/commit/bb4b552be23e20d240056b5eb2b835e3bd3ce388))

* feat(#236): print issue content to terminal when selecting (#246)

Fixes #236 ([`faa954e`](https://github.com/MartinBernstorff/lumberman/commit/faa954e75b9a4b3311cae7760437549001590497))

* feat(#235): self-assign on issue selection

Fixes #235 ([`dfa745b`](https://github.com/MartinBernstorff/lumberman/commit/dfa745b65fb0bf4336feff771b62650756359a73))

* feat(#236): print issue content to terminal when selecting

Fixes #236 ([`3407156`](https://github.com/MartinBernstorff/lumberman/commit/34071567b8f08024d34965c20123b6ad045ba382))

### Refactor

* refactor: remove mvc terminology ([`b4b874f`](https://github.com/MartinBernstorff/lumberman/commit/b4b874f69839f2443ddef51e2774df03bbd7e7ad))


## v0.44.1 (2024-02-19)

### Fix

* fix: misc. ([`3ce15fc`](https://github.com/MartinBernstorff/lumberman/commit/3ce15fce1b05a59daeeb2996186eb6849d06ab1d))

### Refactor

* refactor: unified issue title object (#245)

fix: misc.

update view.py update 7 files ([`baf4832`](https://github.com/MartinBernstorff/lumberman/commit/baf4832cfc928ac6b1cd1930fcb1d24191e3c20b))

### Unknown

* update view.py update 7 files ([`0fdd987`](https://github.com/MartinBernstorff/lumberman/commit/0fdd987ddd8b15ca504158e6ba4712a216b2e043))


## v0.44.0 (2024-02-19)

### Feature

* feat: easier selection of manual prompt (#244) ([`8b3a35f`](https://github.com/MartinBernstorff/lumberman/commit/8b3a35f9c62fdb7a37d2464465e1f4829d13b88c))

* feat: exact matching with fzf ([`2eed06a`](https://github.com/MartinBernstorff/lumberman/commit/2eed06a9eca8735967d3ba129f4bb130715b94d1))

### Unknown

* deps: remove questionary (#243) ([`3d6dfbe`](https://github.com/MartinBernstorff/lumberman/commit/3d6dfbe912a16e84f800a7f92f378bb8895f3677))

* deps: remove questionary ([`ee2867b`](https://github.com/MartinBernstorff/lumberman/commit/ee2867bc5805268c2b5ed471b8e443d8279b1e6f))


## v0.43.0 (2024-02-19)

### Feature

* feat(#237): select with fuzzy finder (#239) ([`4a68824`](https://github.com/MartinBernstorff/lumberman/commit/4a688243b1612ece383702117937d9915fb3a6e5))

* feat(#237): select with fuzzy finder

Fixes #237 ([`0b8ce63`](https://github.com/MartinBernstorff/lumberman/commit/0b8ce63115c574b21c736c161f05a5d81dbd9dcd))

### Unknown

* misc. (#238) ([`7f1660c`](https://github.com/MartinBernstorff/lumberman/commit/7f1660caa736294ec513869db2bc98d30b742d36))

* update view.py ([`7cd7865`](https://github.com/MartinBernstorff/lumberman/commit/7cd78653f43ee9418d99e5e1477152bc3441e6f5))

* misc. ([`1ada069`](https://github.com/MartinBernstorff/lumberman/commit/1ada06968b36c7842bf46a73b845ce1a1ca8ac16))


## v0.42.0 (2024-02-03)

### Feature

* feat(#228): automatically get recent issues if none assigned (#229)

Fixes #228 ([`471e62b`](https://github.com/MartinBernstorff/lumberman/commit/471e62b082f164347e7514249816ec4a918091cf))

* feat(#228): automatically get recent issues if none assigned

Fixes #228 ([`2eebcb7`](https://github.com/MartinBernstorff/lumberman/commit/2eebcb7557f9891549e55d151ec670f6fc009e06))

### Unknown

* Install the CodeSee workflow. (#227) ([`c9d1e27`](https://github.com/MartinBernstorff/lumberman/commit/c9d1e272b058033d8f42e652566045e283a4aa03))

* Install the CodeSee workflow. Learn more at https://docs.codesee.io ([`b4f8171`](https://github.com/MartinBernstorff/lumberman/commit/b4f8171425c392ead67d95115f8419e6d7256154))


## v0.41.0 (2024-01-31)

### Feature

* feat(#212): auto-stash when using checkout (#223)

Fixes #212 ([`ab5bdfa`](https://github.com/MartinBernstorff/lumberman/commit/ab5bdfa1f2ee391a4f7f1ddfecc36420912c750d))

* feat(#212): auto-stash when using checkout

Fixes #212 ([`ffba21f`](https://github.com/MartinBernstorff/lumberman/commit/ffba21f8da9b2d80bbf5b0151871084f9a40605d))


## v0.40.0 (2024-01-31)

### Feature

* feat(#216): allow locations to be specified as positional args in insert (#222)

Fixes #216 ([`e01cd1c`](https://github.com/MartinBernstorff/lumberman/commit/e01cd1c5eec1b5a628731f9bbe1d891680aa72f2))

* feat(#216): allow locations to be specified as positional args in insert

Fixes #216 ([`0b579db`](https://github.com/MartinBernstorff/lumberman/commit/0b579db2a1d94c2ef2f9928ba1ab2f7f9621f07a))


## v0.39.0 (2024-01-29)

### Feature

* feat(#220): sync main before creating new branch on new (#221)

Fixes #220 ([`6858be2`](https://github.com/MartinBernstorff/lumberman/commit/6858be24faac4b3f6d7a77b57a5b901fcea55176))

* feat(#220): sync main before creating new branch on new

Fixes #220 ([`027ccf8`](https://github.com/MartinBernstorff/lumberman/commit/027ccf8f2020696bb263c23fb11a08224cfbc62d))


## v0.38.0 (2024-01-25)

### Feature

* feat: rename create to insert (#214) ([`bb57e20`](https://github.com/MartinBernstorff/lumberman/commit/bb57e20e22a4d0c065695271af53e507d24478e7))

* feat: rename create to insert ([`fde76c5`](https://github.com/MartinBernstorff/lumberman/commit/fde76c59d5362223d172fdefc979a8c25f583dbb))

### Unknown

* update DOCS.md ([`6b5b1f8`](https://github.com/MartinBernstorff/lumberman/commit/6b5b1f81b268ecc533d300b5773d600df1172405))


## v0.37.1 (2024-01-23)

### Fix

* fix: checkout should map to checkout (#210) ([`aac8b88`](https://github.com/MartinBernstorff/lumberman/commit/aac8b88c66be2b1c3f3acf64bc6821fdec4da006))

* fix: checkout should map to checkout ([`4f282ea`](https://github.com/MartinBernstorff/lumberman/commit/4f282ea037e055393c4177ee8297072fa7578f87))

### Unknown

* update DOCS.md ([`c7be067`](https://github.com/MartinBernstorff/lumberman/commit/c7be0671ac3d99521934c6dc52c9e60786313b5b))


## v0.37.0 (2024-01-23)

### Feature

* feat(#208): sync after move (#209)

Fixes #208 ([`2132ea3`](https://github.com/MartinBernstorff/lumberman/commit/2132ea354b76a0708c54942b32b1f91a3e6b738b))


## v0.36.1 (2024-01-23)

### Feature

* feat(#208): sync after move

Fixes #208 ([`0ebc8ef`](https://github.com/MartinBernstorff/lumberman/commit/0ebc8ef46f90bc0849766befc5e3001d0f5c18bc))

### Fix

* fix(#190): queueop should not sync if command failed (#207)

Fixes #190 ([`f3eef36`](https://github.com/MartinBernstorff/lumberman/commit/f3eef363477a74a63c4cebdd90695bff1f912558))

* fix(#190): queueop should not sync if command failed

Fixes #190 ([`68deb74`](https://github.com/MartinBernstorff/lumberman/commit/68deb7491e8231dc3753e5b29416e18c4aa003bd))


## v0.36.0 (2024-01-23)

### Feature

* feat(#204): add checkout command (#205) ([`7e1dc77`](https://github.com/MartinBernstorff/lumberman/commit/7e1dc776831b4fb06a9db90e83d9c8bab18dcdc8))

* feat(#204): add checkout command

Fixes #204 ([`e10d53d`](https://github.com/MartinBernstorff/lumberman/commit/e10d53da295e523dab9ffaec561d88be393fa92b))

### Unknown

* deps(#203): rich should automatically be installed (#206) ([`d8e9bdd`](https://github.com/MartinBernstorff/lumberman/commit/d8e9bdd2c62d0ab6002b3dfb89b5f0e2ad0d8b00))

* deps(#203): rich should automatically be installed

Fixes #203 ([`423f768`](https://github.com/MartinBernstorff/lumberman/commit/423f768177d0335e59cee46324b643e145c7e8f4))

* update DOCS.md ([`824a27d`](https://github.com/MartinBernstorff/lumberman/commit/824a27d0ef1c927b4219ee3df19ebf9ec27ef7e2))


## v0.35.1 (2024-01-22)

### Fix

* fix: simpler annotation ([`4a5c06a`](https://github.com/MartinBernstorff/lumberman/commit/4a5c06a8c418ca1c9a210cf5bdc123bd15d00fbd))

### Unknown

* deps:(deps-dev): bump diff-cover from 8.0.1 to 8.0.3 (#202) ([`9e87fd6`](https://github.com/MartinBernstorff/lumberman/commit/9e87fd64be755cfa8ef4c10edce84022ee0edd5e))

* deps:(deps-dev): bump diff-cover from 8.0.1 to 8.0.3

Bumps [diff-cover](https://github.com/Bachmann1234/diff-cover) from 8.0.1 to 8.0.3.
- [Release notes](https://github.com/Bachmann1234/diff-cover/releases)
- [Changelog](https://github.com/Bachmann1234/diff_cover/blob/main/CHANGELOG)
- [Commits](https://github.com/Bachmann1234/diff-cover/compare/v8.0.1...v8.0.3)

---
updated-dependencies:
- dependency-name: diff-cover
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`7d6cb94`](https://github.com/MartinBernstorff/lumberman/commit/7d6cb9473245f0d61eb1cd045a32f6afe3c55ccb))


## v0.35.0 (2024-01-22)

### Feature

* feat(#198): rename status to log (#199)

Fixes #198 ([`cb2ebc2`](https://github.com/MartinBernstorff/lumberman/commit/cb2ebc26c4244f98d64ed1af521f137c9879b62f))


## v0.34.0 (2024-01-22)

### Documentation

* docs: move docs outside of readme (#193) ([`8a80470`](https://github.com/MartinBernstorff/lumberman/commit/8a804700500c258f45afbcb28e5dfd72c0486c42))

* docs: move docs outside of readme ([`fe2743d`](https://github.com/MartinBernstorff/lumberman/commit/fe2743df13252001498fd8bb1cef79000efe28f4))

* docs: add docs to readme (#192) ([`c1dbe66`](https://github.com/MartinBernstorff/lumberman/commit/c1dbe660c954c81cceef00747c63530603341386))

* docs: add docs to readme ([`530dd82`](https://github.com/MartinBernstorff/lumberman/commit/530dd8294a58cb45af7db5f2fc006e419a2d0afd))

### Feature

* feat(#198): rename status to log

Fixes #198 ([`7ff230a`](https://github.com/MartinBernstorff/lumberman/commit/7ff230a97e7ba45c560ff281a366a724e6aa1b16))

* feat(#196): rename add to create (#197)

Fixes #196 ([`a82eea7`](https://github.com/MartinBernstorff/lumberman/commit/a82eea7a51f5c7d78e26bb7c8c48eff0ab6bc31e))

* feat(#196): rename add to create

Fixes #196 ([`e64e836`](https://github.com/MartinBernstorff/lumberman/commit/e64e836389c52be451ae0c286f18126fcd5b0f29))

### Refactor

* refactor: misc. (#195) ([`cb2d4f9`](https://github.com/MartinBernstorff/lumberman/commit/cb2d4f9e83ceba65c188ded69b3e402cd60810bc))

* refactor: misc. ([`6366e3d`](https://github.com/MartinBernstorff/lumberman/commit/6366e3d72b674efe396ff1b856f98756e9ac94bb))

### Unknown

* Update README.md ([`43e6f76`](https://github.com/MartinBernstorff/lumberman/commit/43e6f763676eb99de071b125cdccdc0e0ef9443c))

* dev: do not auto-add after submitting (#194) ([`1f0170f`](https://github.com/MartinBernstorff/lumberman/commit/1f0170fc3e6ae3155d053c3cac1605c51d83ccbd))

* dev: do not auto-add after submitting ([`e4eddfb`](https://github.com/MartinBernstorff/lumberman/commit/e4eddfb4655c4494e85faad403c569bfc45eca3b))


## v0.33.0 (2024-01-18)

### Feature

* feat: rename to lumberman (#191) ([`0fb9106`](https://github.com/MartinBernstorff/lumberman/commit/0fb91061d5f9fb1cfe2ae6e4cbc21f3ffbf163ce))

* feat: rename to lumberman ([`cfc6cd9`](https://github.com/MartinBernstorff/lumberman/commit/cfc6cd9b10bf21f0c45ecc613929db0b24d1da70))

### Refactor

* refactor: simplify navigator (#189) ([`e964fc8`](https://github.com/MartinBernstorff/lumberman/commit/e964fc87fa033edde08504714ca1a94ef0c1aa26))

* refactor: simplify navigator ([`0d56a86`](https://github.com/MartinBernstorff/lumberman/commit/0d56a86ab2a496332f79b86694ead04458fb689b))

* refactor: use stacking terminology (#188) ([`afefbd3`](https://github.com/MartinBernstorff/lumberman/commit/afefbd3b4616f1997c88e4a334b1782e16ed86a8))

* refactor: use stacking terminology ([`e93f6a1`](https://github.com/MartinBernstorff/lumberman/commit/e93f6a1bfd9453425a5e2650b348e66dce48f0dd))


## v0.32.1 (2024-01-18)

### Performance

* perf: decrease remote syncs (#186) ([`e1da04d`](https://github.com/MartinBernstorff/lumberman/commit/e1da04dbbac9d1c15c47512e9e3be26e1fba35ce))

* perf: decrease remote syncs ([`eb7de2c`](https://github.com/MartinBernstorff/lumberman/commit/eb7de2cf6b238ab6cba2b66710c49d41455806e1))

### Unknown

* dev: disable pager on devcontainer start (#185) ([`f9fa218`](https://github.com/MartinBernstorff/lumberman/commit/f9fa218ef930140c0285d1ab4f714981fe767044))

* dev: disable pager on devcontainer start ([`a632fca`](https://github.com/MartinBernstorff/lumberman/commit/a632fca3597904462c9bef885399710c83e7f774))


## v0.32.0 (2024-01-18)

### Feature

* feat: show status after navigation (#183) ([`326afb7`](https://github.com/MartinBernstorff/lumberman/commit/326afb73ee3ee1c7b2eff4ba57d69ea1461ec467))

* feat: show status after navigation ([`c664803`](https://github.com/MartinBernstorff/lumberman/commit/c664803dd49e8052842b40b24ba7ed4d027962a6))

* feat(#169): support syncing to draft PRs (#182)

feat(#169): support syncing to draft PRs

Fixes #169

misc. ([`3f6a574`](https://github.com/MartinBernstorff/lumberman/commit/3f6a574473cf38d335ed5b7d2c49198db5f34165))

* feat(#169): support syncing to draft PRs

Fixes #169 ([`14fe707`](https://github.com/MartinBernstorff/lumberman/commit/14fe7076581c2ef78087714a42442289596e64ea))

### Performance

* perf: do not double-sync (#184) ([`f84b6c3`](https://github.com/MartinBernstorff/lumberman/commit/f84b6c33b61436f89a7e547aa31203061ad10a4d))

* perf: do not double-sync ([`d3a487c`](https://github.com/MartinBernstorff/lumberman/commit/d3a487cad43da4287258eb45cadc364d9c6c3c96))


## v0.31.0 (2024-01-18)

### Feature

* feat(#173 &amp; #174): add move and delete (#181)

Fixes #174

Fixes #173 ([`96f26dc`](https://github.com/MartinBernstorff/lumberman/commit/96f26dcd59ca2e7e16f4a6b528f99ea7c0e8b13c))


## v0.30.0 (2024-01-18)

### Feature

* feat(#173 &amp; #174): add move and delete

Fixes #174

Fixes #173 ([`83864f9`](https://github.com/MartinBernstorff/lumberman/commit/83864f916b35cea8b67f61db25dbbe3014200de3))

* feat(#178): automatic app command parsing (#180)

Fixes #178 ([`b5ae288`](https://github.com/MartinBernstorff/lumberman/commit/b5ae288c29deeb54f7f5d732fe1a77c9a68d987c))

* feat(#178): automatic app command parsing

Fixes #178 ([`5f7c13d`](https://github.com/MartinBernstorff/lumberman/commit/5f7c13d035c76ad0e6f3c80ab273e839f0e38841))

### Refactor

* refactor: MVC for main (#179) ([`801b7ae`](https://github.com/MartinBernstorff/lumberman/commit/801b7ae7b8d07b42a46c731df7fedbf02f51c683))

* refactor: MVC for main ([`207d18c`](https://github.com/MartinBernstorff/lumberman/commit/207d18ccc1c84bdba542f81dd879c319a2c736e9))


## v0.29.0 (2024-01-17)

### Feature

* feat(#127): periodically squash commits to make rebasing easier (#170)

Fixes #127 ([`7004692`](https://github.com/MartinBernstorff/lumberman/commit/7004692375777dffb8611d199107eca6ae3ad7d9))

### Unknown

* Update devcontainer.json ([`e2fd4c8`](https://github.com/MartinBernstorff/lumberman/commit/e2fd4c8c454e1741f292bccd4116128030de5c50))

* Update devcontainer.json ([`878f8d8`](https://github.com/MartinBernstorff/lumberman/commit/878f8d8c24bee7b84d0e357cacfff65e80eb67cc))

* Update devcontainer.json ([`8c50f7d`](https://github.com/MartinBernstorff/lumberman/commit/8c50f7d5a18ba49c216cd48bad8a20aefe079302))


## v0.28.0 (2024-01-17)

### Documentation

* docs(#162): add docstrings to CLI commands (#167)

Fixes #162

@HLasse Would love if you have any feedback here! ([`2880361`](https://github.com/MartinBernstorff/lumberman/commit/2880361fe2321a338401a8c2873e7f392b35c22b))

* docs(#162): add docstrings to CLI commands

Fixes #162 ([`4e9eeb2`](https://github.com/MartinBernstorff/lumberman/commit/4e9eeb26b959f2560c28399982cc86fceffb4abe))

### Feature

* feat(#127): periodically squash commits to make rebasing easier

Fixes #127 ([`a0df305`](https://github.com/MartinBernstorff/lumberman/commit/a0df3052051e48211127c7910e0d7c677c93ecaf))

* feat(#161): sync command (#168) ([`8a5e4b5`](https://github.com/MartinBernstorff/lumberman/commit/8a5e4b57d5c12159e58ade3ac8abfe1382169cd4))

* feat(#161): sync command

Fixes #161 ([`0273f3c`](https://github.com/MartinBernstorff/lumberman/commit/0273f3c10490ff6ac2ac77b3f5a56e5c1864404a))

### Unknown

* misc. ([`99f9222`](https://github.com/MartinBernstorff/lumberman/commit/99f9222b7522e73fedb352d7c1c820f2278578b8))

* misc. ([`9fef4d5`](https://github.com/MartinBernstorff/lumberman/commit/9fef4d5c17cbd60b78f3a9ef9ee9e171eb06d62d))

* misc. ([`400bcc0`](https://github.com/MartinBernstorff/lumberman/commit/400bcc056d707ae55e2a692f103ea9f187bf9631))

* misc. ([`636e409`](https://github.com/MartinBernstorff/lumberman/commit/636e409d1e2bac2d68cc2363c4cf3ff9e1a1939a))

* misc. ([`8f033c3`](https://github.com/MartinBernstorff/lumberman/commit/8f033c30a5c9a8002ce77a735a8bab4fe1a8b4e1))

* misc. ([`2cc9883`](https://github.com/MartinBernstorff/lumberman/commit/2cc9883381acd4be1c1dd1f797b8851b9718cc96))


## v0.27.0 (2024-01-17)

### Feature

* feat(#163): show help if no command provided (#165)

feat(#163): show help if no command provided

Fixes #163

misc. ([`d4280a7`](https://github.com/MartinBernstorff/lumberman/commit/d4280a755bebce6fdfbdb7dfe331cfe3b64b051a))

* feat(#163): show help if no command provided

Fixes #163 ([`fb5c7aa`](https://github.com/MartinBernstorff/lumberman/commit/fb5c7aa96ccdf8c6af1811bffaefe47ab82734ac))

### Fix

* fix(#164): remove single-letter aliases from help output (#166)

fix(#164): remove single-letter aliases from help output

Fixes #164

misc. ([`9375159`](https://github.com/MartinBernstorff/lumberman/commit/9375159f1a2fdaf877b83a043185479618c7adad))

* fix(#164): remove single-letter aliases from help output

Fixes #164 ([`02f5822`](https://github.com/MartinBernstorff/lumberman/commit/02f582222cfc57e24cdc27fc89123235e13b6d3b))

### Unknown

* misc. ([`874bec2`](https://github.com/MartinBernstorff/lumberman/commit/874bec22b1a217a27631e69f92afc05ba1a5e409))

* misc. ([`0d50a56`](https://github.com/MartinBernstorff/lumberman/commit/0d50a5690c3a38993258c33fc4fd8e40842b1c7e))


## v0.26.0 (2024-01-17)

### Feature

* feat: bump version ([`c34c33c`](https://github.com/MartinBernstorff/lumberman/commit/c34c33cfcd34aee4e4e4fa9684f294ef3b2535dd))

### Refactor

* refactor: simplify issue stringification (#158)

refactor: simplify issue stringification

misc. ([`e382408`](https://github.com/MartinBernstorff/lumberman/commit/e38240821be707d7f6a4c258eb64fbcbc374a90f))

### Unknown

* Update queue_manipulator.py (#160) ([`a193ebd`](https://github.com/MartinBernstorff/lumberman/commit/a193ebd5dba0c342a7ec6fbd4be9a971d4a11b61))

* Update queue_manipulator.py ([`e9c5cdc`](https://github.com/MartinBernstorff/lumberman/commit/e9c5cdcd118a8b081d7dd45b3a4ca215a4c5600f))


## v0.25.1 (2024-01-16)

### Fix

* fix(#99): handle lack of prefix gracefully (#157) ([`3fe766b`](https://github.com/MartinBernstorff/lumberman/commit/3fe766b736df980b85efb10978faa37e3aed18b1))

* fix(#99): handle lack of prefix gracefully

Fixes #99 ([`8d8f2b8`](https://github.com/MartinBernstorff/lumberman/commit/8d8f2b8715179b0a1c768822dc04b8eb126e55e5))

### Refactor

* refactor: simplify issue stringification ([`2c1aeaa`](https://github.com/MartinBernstorff/lumberman/commit/2c1aeaa85fc4f719479a4064431ea4dee301e9ad))

### Unknown

* misc. ([`8d2b215`](https://github.com/MartinBernstorff/lumberman/commit/8d2b2157cf1007f37485c7bbc50d631667edca9f))

* misc. ([`5783312`](https://github.com/MartinBernstorff/lumberman/commit/5783312d2809dbed1ab12d282d82a3849d9a5baa))

* misc. ([`22ba1a6`](https://github.com/MartinBernstorff/lumberman/commit/22ba1a6ca27376cf229caf51566f6159e75d2a1e))


## v0.25.0 (2024-01-16)

### Feature

* feat(#153): simplify branch name (#156) ([`53843db`](https://github.com/MartinBernstorff/lumberman/commit/53843dbfde22cbe95bf5d5864964b6ac2f65c154))

* feat(#153): simplify branch name

Fixes #153 ([`0b8a7bc`](https://github.com/MartinBernstorff/lumberman/commit/0b8a7bcf3a4846457d0acc71325131ad19c09d81))

### Fix

* fix(#133): remove double --json in get_issues_assigned_to_me (#154)

fix(#133): remove double --json in get_issues_assigned_to_me

Fixes #133

misc. ([`9b9a898`](https://github.com/MartinBernstorff/lumberman/commit/9b9a898e0aff28fc3bab4d03f7f3b3156540f54a))

### Unknown

* misc. ([`b18cc6e`](https://github.com/MartinBernstorff/lumberman/commit/b18cc6e9f57fdd8dc4068b62809f61796392d454))

* misc. ([`cd94f92`](https://github.com/MartinBernstorff/lumberman/commit/cd94f92e4a56630a3741f88a8d78258d7d5a1b91))


## v0.24.0 (2024-01-16)

### Feature

* feat: add new ([`9d9bd4a`](https://github.com/MartinBernstorff/lumberman/commit/9d9bd4ad303a2ab0c847f73a51981b7de2579a7e))

### Fix

* fix(#133): remove double --json in get_issues_assigned_to_me

Fixes #133 ([`b5fd29b`](https://github.com/MartinBernstorff/lumberman/commit/b5fd29b04fb883d0c928db345592748e8c5d2111))

* fix(#149): fork back does not fork (#152) ([`22cf251`](https://github.com/MartinBernstorff/lumberman/commit/22cf251011634f263e0e4988fb7bc5cb2842f4d1))

* fix(#149): fork back does not fork

Fixes #149 ([`48737b7`](https://github.com/MartinBernstorff/lumberman/commit/48737b7e50f27e36f04d695f53ee100d2cc09d2a))

### Unknown

* misc. ([`71f3850`](https://github.com/MartinBernstorff/lumberman/commit/71f38500e25feb8cd863c6b85170e80d4de42f74))

* misc. ([`5bc5c33`](https://github.com/MartinBernstorff/lumberman/commit/5bc5c335f135309067ccb200f203895a2c429f79))


## v0.23.2 (2024-01-16)

### Fix

* fix(#146): add before adds after (#151)

fix(#146): add before adds after

Fixes #146

misc. ([`4221d63`](https://github.com/MartinBernstorff/lumberman/commit/4221d6397d34c64799efd4eea2fc2aff4396fb96))

* fix(#146): add before adds after

Fixes #146 ([`439c8e3`](https://github.com/MartinBernstorff/lumberman/commit/439c8e327fd5a602d87bbd89891fb64ab2c325a5))

### Unknown

* misc. ([`ca1ca75`](https://github.com/MartinBernstorff/lumberman/commit/ca1ca7527839a143c52b54a22721cfad247470c6))


## v0.23.1 (2024-01-15)

### Fix

* fix: avoid double-commit on new branch (#145) ([`4fc214d`](https://github.com/MartinBernstorff/lumberman/commit/4fc214da25231dc069656b09cccfee154d77fdb2))

* fix: avoid double-commit on new branch ([`e68f1a8`](https://github.com/MartinBernstorff/lumberman/commit/e68f1a8989082943337a390a839d2433641bce07))

### Refactor

* refactor: simplify new branch creation (#144)

refactor: simplify new branch creation

refactor: simplify new branch creation ([`ee8b9eb`](https://github.com/MartinBernstorff/lumberman/commit/ee8b9eba6fa03ffeb88819de567de70e963e93ca))

* refactor: simplify new branch creation ([`326f568`](https://github.com/MartinBernstorff/lumberman/commit/326f568949dea0cb04f75d797b353434f1c6a51e))

* refactor: simplify new branch creation ([`9a2a7a7`](https://github.com/MartinBernstorff/lumberman/commit/9a2a7a7daaf60d74bc5bea08542f42c0a132374d))

### Unknown

* Revert &#34;feat: remove fork command&#34; (#143) ([`ba5b611`](https://github.com/MartinBernstorff/lumberman/commit/ba5b61183495d74872e669b0dca789c67b8943bf))

* Revert &#34;feat: remove fork command&#34; ([`6791039`](https://github.com/MartinBernstorff/lumberman/commit/67910399c8142d006daad9cc3ef98a149ce63462))

* dev: disable isort split on trailing comma (#142) ([`12734a1`](https://github.com/MartinBernstorff/lumberman/commit/12734a16eaff1b9cac1f5a7a0b8b48e5ccf512bb))

* dev: disable isort split on trailing comma ([`982e084`](https://github.com/MartinBernstorff/lumberman/commit/982e084d6e1cd69c0f0de793f3080a5cca6f2aad))


## v0.23.0 (2024-01-15)

### Feature

* feat: remove fork command (#141)

Fixes #140. ([`fb37eb1`](https://github.com/MartinBernstorff/lumberman/commit/fb37eb1d5ee20e5753739fc3efe5ec0b4f799d25))


## v0.22.4 (2024-01-15)

### Feature

* feat: remove fork command

Fixes #140. ([`5059d90`](https://github.com/MartinBernstorff/lumberman/commit/5059d9039571fc219f58763fe65401756965eac5))

### Fix

* fix(#88): herb add front does not automatically restack (#139)

fix(#88): herb add front does not automatically restack

Fixes #88

fix: go to front should go to trunk ([`75ed735`](https://github.com/MartinBernstorff/lumberman/commit/75ed735f7782acd99499cc1cf63fe61d04e8e41e))


## v0.22.3 (2024-01-15)

### Fix

* fix: go to front should go to trunk ([`493a70a`](https://github.com/MartinBernstorff/lumberman/commit/493a70a51e428b18c47d519f9a5b252f3ebcbccc))

* fix: locations for cli (#137) ([`0d11195`](https://github.com/MartinBernstorff/lumberman/commit/0d111956d4426be6a21eedfd73bc9f72e03cfbfb))

* fix: locations for cli ([`d66aaac`](https://github.com/MartinBernstorff/lumberman/commit/d66aaacb4bc7ce8c136ad6e88b65138850533e32))

### Style

* style: lint (#138)

style: lint

style: lint ([`919e244`](https://github.com/MartinBernstorff/lumberman/commit/919e24497f9fbc33ebbcce68dd7cb5b19a53dd5b))

* style: lint ([`b27d3db`](https://github.com/MartinBernstorff/lumberman/commit/b27d3db74a5a6b2653490c51695d73a68045fd04))

* style: lint ([`4e6068a`](https://github.com/MartinBernstorff/lumberman/commit/4e6068a3315d84eb58399046bf93cfa894b6d151))


## v0.22.2 (2024-01-15)

### Fix

* fix(#135): sanitise  when creating branch (#136)

Fixes #135 ([`4b10945`](https://github.com/MartinBernstorff/lumberman/commit/4b10945232440bd3a9c7a223f3f5b22e663d102d))

* fix(#135): sanitise  when creating branch

Fixes #135 ([`8a8af4d`](https://github.com/MartinBernstorff/lumberman/commit/8a8af4d71c2d154a743176230b0cdf6f260c29aa))


## v0.22.1 (2024-01-15)

### Fix

* fix: getting recent issues crashes (#134)

Fixes #130. ([`043f3c2`](https://github.com/MartinBernstorff/lumberman/commit/043f3c2ded7da3a61c90d1fb08f6dfc0d51c2f56))

* fix: getting recent issues crashes

Fixes #130. ([`48e3e55`](https://github.com/MartinBernstorff/lumberman/commit/48e3e5587e382ebdb8e776ed1b8c858d5d97b14f))

### Unknown

* deps:(deps-dev): bump pyright from 1.1.333 to 1.1.346 (#128) ([`d88f075`](https://github.com/MartinBernstorff/lumberman/commit/d88f075095c001a984c95b35edf2079720c8b949))

* deps:(deps-dev): bump ruff from 0.1.2 to 0.1.13 (#129) ([`7b2232c`](https://github.com/MartinBernstorff/lumberman/commit/7b2232c654c930fca8a9b04d50b35b6b180fb55e))


## v0.22.0 (2024-01-15)

### Feature

* feat: bump version ([`f0ef023`](https://github.com/MartinBernstorff/lumberman/commit/f0ef0233bb77dd768b112c585394266976e687d5))

### Unknown

* misc. (#132) ([`797c862`](https://github.com/MartinBernstorff/lumberman/commit/797c8629f8906c08926a696092e17d7700996fd2))

* misc. ([`297a5e9`](https://github.com/MartinBernstorff/lumberman/commit/297a5e957ac2d653ed1c56b1d44cbef81a6f5145))

* deps:(deps-dev): bump ruff from 0.1.2 to 0.1.13

Bumps [ruff](https://github.com/astral-sh/ruff) from 0.1.2 to 0.1.13.
- [Release notes](https://github.com/astral-sh/ruff/releases)
- [Changelog](https://github.com/astral-sh/ruff/blob/main/CHANGELOG.md)
- [Commits](https://github.com/astral-sh/ruff/compare/v0.1.2...v0.1.13)

---
updated-dependencies:
- dependency-name: ruff
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`0cf6f07`](https://github.com/MartinBernstorff/lumberman/commit/0cf6f07c31f5c0030a59f6214cb6a2bcd2f6b5de))

* deps:(deps-dev): bump pyright from 1.1.333 to 1.1.346

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.333 to 1.1.346.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.333...v1.1.346)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`e886bd2`](https://github.com/MartinBernstorff/lumberman/commit/e886bd286524563c3d670665d32b65ffc89e6751))


## v0.21.0 (2024-01-15)

### Feature

* feat(#118): show select issue dialog when no issues assigned to the user (#124)

feat(#118): show select issue dialog when no issues assigned to the user

Fixes #118

misc.

misc ([`119723f`](https://github.com/MartinBernstorff/lumberman/commit/119723f82159d4b95e5c12897d90c1ffc0491b4d))

* feat(#118): show select issue dialog when no issues assigned to the user

Fixes #118 ([`5fd2da8`](https://github.com/MartinBernstorff/lumberman/commit/5fd2da8c01e78bb5678e20b1d18e69a045f7fb89))

### Unknown

* misc. ([`b763b7f`](https://github.com/MartinBernstorff/lumberman/commit/b763b7fa731c0f11871f0f55c202397aed1c9c63))

* misc ([`4c48b07`](https://github.com/MartinBernstorff/lumberman/commit/4c48b07a5d3277e08427637dadcc4582c23fc6e5))

* misc. ([`43e5955`](https://github.com/MartinBernstorff/lumberman/commit/43e5955fcaa1e624c8de02dde7ede14675aa6037))


## v0.20.3 (2024-01-15)

### Fix

* fix: add and fork require quotations surrounds (#123)

. ([`df31f94`](https://github.com/MartinBernstorff/lumberman/commit/df31f941f7effbc390547cceaa09cf339a78d7e7))


## v0.20.2 (2024-01-15)

### Fix

* fix(#90): branch-name-generation-inserts-dashes-for-spaces (#122)

fix(#90): branch-name-generation-inserts-dashes-for-spaces

Fixes #90

misc.

misc.

misc ([`763e7d3`](https://github.com/MartinBernstorff/lumberman/commit/763e7d36e0a016a6c218d1fdeac562848f29b3d4))

* fix(#90): branch-name-generation-inserts-dashes-for-spaces

Fixes #90 ([`3d5c522`](https://github.com/MartinBernstorff/lumberman/commit/3d5c52206b9682434569ac3ef80b1f12f3e81dc3))

### Refactor

* refactor(#62): rename instances of stacker to queuer

Fixes #62 ([`44c5df8`](https://github.com/MartinBernstorff/lumberman/commit/44c5df80aad26c39c375287b348fcfe4fb654ed3))

### Unknown

* misc ([`abbdf72`](https://github.com/MartinBernstorff/lumberman/commit/abbdf72bc89fb56b0f901e8325b24eba69719a49))

* misc. ([`d7695e7`](https://github.com/MartinBernstorff/lumberman/commit/d7695e791fd67ceb1e4893a826d5ced87a5b7318))

* misc. ([`6a09dfc`](https://github.com/MartinBernstorff/lumberman/commit/6a09dfcdc2d45d847bdfbe27b6f7fe4d2d4e9c80))


## v0.20.1 (2024-01-15)

### Fix

* fix: commit-string-correctly ([`e9ed5ae`](https://github.com/MartinBernstorff/lumberman/commit/e9ed5aecbfd570f2e53f9cba67db1677279a2f2e))

### Performance

* perf(#119): do-not-sync-branches-before-showing-issue-selector (#121)

perf(#119): do-not-sync-branches-before-showing-issue-selector

Fixes #119

misc. ([`cebeede`](https://github.com/MartinBernstorff/lumberman/commit/cebeedee90fb57eebb967a2de2bd3efe62b3ccff))

* perf(#119): do-not-sync-branches-before-showing-issue-selector

Fixes #119 ([`c7afe0f`](https://github.com/MartinBernstorff/lumberman/commit/c7afe0fec83f9d730d768102e157b828e3ceacd5))

### Unknown

* misc. ([`94be8f8`](https://github.com/MartinBernstorff/lumberman/commit/94be8f88bbb1bd69ea10d69b2f8b6294cf0becad))

* misc. ([`11cfaf2`](https://github.com/MartinBernstorff/lumberman/commit/11cfaf286d9da12bd0de1bca500ebffff3bc30f1))


## v0.20.0 (2024-01-13)

### Feature

* feat: select from 10 most recent issues (issue #71) (#72)

Fixes #71 ([`3ec5c56`](https://github.com/MartinBernstorff/lumberman/commit/3ec5c568fddc708aef5caf91031a16827ef66957))

### Refactor

* refactor: misc. (#116)

refactor: misc.

refactor: misc. ([`d812453`](https://github.com/MartinBernstorff/lumberman/commit/d812453ffc5bc89808586f383cf443386ff2b983))

### Unknown

* misc. ([`d0cadbd`](https://github.com/MartinBernstorff/lumberman/commit/d0cadbd4d782f2f6a2c74b163d3bb549f0e206dd))

* misc. ([`dbf38cc`](https://github.com/MartinBernstorff/lumberman/commit/dbf38cc9b552a223c2e72d7da451656d26666042))

* misc. ([`5e7bbca`](https://github.com/MartinBernstorff/lumberman/commit/5e7bbca305e563164008cf08582477959b531e38))

* misc. ([`19436ef`](https://github.com/MartinBernstorff/lumberman/commit/19436ef65aa473b17e4162420ca67e799fae390d))

* dev: allow-skipping-sync-on-herb-add (#117)

dev: allow-skipping-sync-on-herb-add

dev: allow-skipping-sync-on-herb-add

misc. ([`d8979fd`](https://github.com/MartinBernstorff/lumberman/commit/d8979fdd0b7861a3ffb3684363d913dd8ef37ef5))

* misc. ([`642199e`](https://github.com/MartinBernstorff/lumberman/commit/642199e87536500282dfe3c8a4de805b84a131c2))

* dev: allow-skipping-sync-on-herb-add ([`d99a48c`](https://github.com/MartinBernstorff/lumberman/commit/d99a48c1fa14e88668e1da99641932e3d42fa79e))


## v0.19.0 (2024-01-13)

### Feature

* feat(#110): on-submit-mark-issue-as-in-progress (#112)

feat(#110): on-submit-mark-issue-as-in-progress

Fixes #110

misc.

misc ([`d33c4c8`](https://github.com/MartinBernstorff/lumberman/commit/d33c4c8df0690afb279219034e21c3d79eb8b3bf))

* feat(#110): on-submit-mark-issue-as-in-progress

Fixes #110 ([`81eb964`](https://github.com/MartinBernstorff/lumberman/commit/81eb964992e66c78e704dc500468b99b0276c33e))

### Fix

* fix: correct issue selection ([`0cb5cf9`](https://github.com/MartinBernstorff/lumberman/commit/0cb5cf9795eddf849950608e63bddc668b21aee0))

### Refactor

* refactor: misc. ([`61e8422`](https://github.com/MartinBernstorff/lumberman/commit/61e8422357633c0cce9365fe0d000c9ee4f630ab))

### Unknown

* misc. ([`fd4a4b0`](https://github.com/MartinBernstorff/lumberman/commit/fd4a4b0ef172cea86f4c2facd7be67ff73f904ea))

* misc ([`61e435d`](https://github.com/MartinBernstorff/lumberman/commit/61e435d024dd7177806424e136ac9759456bf709))

* misc. ([`49645da`](https://github.com/MartinBernstorff/lumberman/commit/49645da267e3678c02882957729c0ce222833992))

* dev: automatically-submit-and-ask-for-next-issue (#109)

dev: automatically-submit-and-ask-for-next-issue

dev: automatically-submit-and-ask-for-next-issue ([`8a83dd9`](https://github.com/MartinBernstorff/lumberman/commit/8a83dd97d2bf4b277f09aba966688556f5f369cf))

* dev: automatically-submit-and-ask-for-next-issue ([`1f8fa3a`](https://github.com/MartinBernstorff/lumberman/commit/1f8fa3a9194ce19f3686a1b885c94bc94d19a624))


## v0.18.0 (2024-01-13)

### Feature

* feat: delete-merged-branches-on-sync (#108)

feat: delete-merged-branches-on-sync

feat: delete-merged-branches-on-sync ([`c2ed5d8`](https://github.com/MartinBernstorff/lumberman/commit/c2ed5d8f04cf4008e6fe6474a7a0fed96136ddd6))

* feat: delete-merged-branches-on-sync ([`9822bd7`](https://github.com/MartinBernstorff/lumberman/commit/9822bd79b535d87b7586f5bdb73eecb5ea99c559))


## v0.17.0 (2024-01-13)

### Feature

* feat(#103): support-aliases-for-commands-and-locations (#106)

feat(#103): support-aliases-for-commands-and-locations

Fixes #103

misc.

misc.

misc. ([`a18d976`](https://github.com/MartinBernstorff/lumberman/commit/a18d9769da412fa069b50467d65b7e1c06b83ffb))

### Fix

* fix(#104): automerge-is--merge-when-ready-in-graphite (#107)

fix(#104): automerge-is--merge-when-ready-in-graphite

Fixes #104

misc. ([`d587bf4`](https://github.com/MartinBernstorff/lumberman/commit/d587bf4770417104ced54a380ec75a752fad3eb8))

### Unknown

* misc. ([`5259014`](https://github.com/MartinBernstorff/lumberman/commit/5259014481d7c4f00d6b366580b9950fc7b36fd5))


## v0.16.0 (2024-01-13)

### Feature

* feat(#103): support-aliases-for-commands-and-locations

Fixes #103 ([`e6c88a5`](https://github.com/MartinBernstorff/lumberman/commit/e6c88a52f820f30e5e7978581e981b7d13c0b045))

* feat: implement-new-vocabulary (#102)

feat: implement-new-vocabulary

misc.

misc.

misc.

misc.

misc.

misc.

misc.

misc.

misc.

lint

misc. ([`3f15589`](https://github.com/MartinBernstorff/lumberman/commit/3f15589dcebed46ab106b2353540fb9be04956ec))

* feat: implement-new-vocabulary ([`8a09bde`](https://github.com/MartinBernstorff/lumberman/commit/8a09bde24b0c3234df0ca9640efb22e42d8811e7))

### Unknown

* misc. ([`f7520f5`](https://github.com/MartinBernstorff/lumberman/commit/f7520f576b4e754014cca85e53540ed186c41778))

* misc. ([`479b68c`](https://github.com/MartinBernstorff/lumberman/commit/479b68ca452f04429370e74ee5a960ed510879d2))

* misc. ([`241be46`](https://github.com/MartinBernstorff/lumberman/commit/241be460e46f93ff8cca4a0d633b696d4784e3ec))

* misc. ([`bfce67f`](https://github.com/MartinBernstorff/lumberman/commit/bfce67f564238773188e46ffb3027aed692f6895))

* misc. ([`f1bbed8`](https://github.com/MartinBernstorff/lumberman/commit/f1bbed8c8a2a6c830d2947f0464396e54ec2eee8))

* misc. ([`6c9b0df`](https://github.com/MartinBernstorff/lumberman/commit/6c9b0dfb2337898575ec1827881c85c878fdfe86))

* misc. ([`ab08fdf`](https://github.com/MartinBernstorff/lumberman/commit/ab08fdfc6c9b46077bbc299513bd8676ae3d427a))

* lint ([`5db9b57`](https://github.com/MartinBernstorff/lumberman/commit/5db9b57248b976f4922f9d64cf949b9b49de34b6))

* misc. ([`e11c540`](https://github.com/MartinBernstorff/lumberman/commit/e11c5402f40bfdc7af20353d05fe8fc292af4b0a))

* misc. ([`7d5bb3a`](https://github.com/MartinBernstorff/lumberman/commit/7d5bb3a79d78e05da70e4a5984e13691d276e5d4))

* misc. ([`b7a52c8`](https://github.com/MartinBernstorff/lumberman/commit/b7a52c81c13aed9a67019e5b0d8847a6214dd440))

* misc. ([`2726f85`](https://github.com/MartinBernstorff/lumberman/commit/2726f8519c3ee2137e872f673b5a1c38dfc4f886))

* misc. ([`3311ecb`](https://github.com/MartinBernstorff/lumberman/commit/3311ecbcb5fde71fa1789b8847fb84c27b0f445d))

* misc. ([`867d3a5`](https://github.com/MartinBernstorff/lumberman/commit/867d3a52500a444a515ac9c86f76746aa6dff98f))

* misc. ([`a50158c`](https://github.com/MartinBernstorff/lumberman/commit/a50158cfc38c4fb61cc699846a42e03dade3e1eb))

* misc. ([`7741123`](https://github.com/MartinBernstorff/lumberman/commit/7741123fbcb3642f93e24eb72210ca23856a3db6))

* misc. ([`9f6d5e8`](https://github.com/MartinBernstorff/lumberman/commit/9f6d5e823770706a67634021beb4c77147f7c47f))


## v0.15.0 (2024-01-13)

### Feature

* feat: implement-QueueNavigator (#101)

feat: implement-QueueNavigator

misc.

misc. ([`2de54db`](https://github.com/MartinBernstorff/lumberman/commit/2de54dbf1fc06933623bea3cba54268dca87d5b5))


## v0.14.0 (2024-01-13)

### Feature

* feat: implement-QueueNavigator ([`c69f2df`](https://github.com/MartinBernstorff/lumberman/commit/c69f2dfdb11f458ae6748c9f997a721713448c6a))

* feat(#91): implement-go-to-front (#100)

feat(#91): implement-go-to-front

Fixes #91

misc.

misc. ([`50bd9fe`](https://github.com/MartinBernstorff/lumberman/commit/50bd9fe79a3ff91d5dc9c348b3d5e7780a857d16))

* feat(#91): implement-go-to-front

Fixes #91 ([`d9dd1a9`](https://github.com/MartinBernstorff/lumberman/commit/d9dd1a96a0bd80faabc055f0536a6e957ba33239))

### Unknown

* misc. ([`a3ca5c4`](https://github.com/MartinBernstorff/lumberman/commit/a3ca5c44eef75143ddfc1c5495c573bbbe2b7fcd))

* misc. ([`fa933e9`](https://github.com/MartinBernstorff/lumberman/commit/fa933e94edb99ea9a2115d1d36f7a6bb608845c0))

* misc. ([`ce80502`](https://github.com/MartinBernstorff/lumberman/commit/ce80502073bccc1daa0fd5513d782c44479dbd5f))

* misc. ([`49eb56f`](https://github.com/MartinBernstorff/lumberman/commit/49eb56f864a3b37df4872b88425353a0843fbe1b))


## v0.13.1 (2024-01-10)

### Performance

* perf: no-need-to-sync-before-submit (#87)

perf: no-need-to-sync-before-submit

perf: no-need-to-sync-before-submit ([`4662466`](https://github.com/MartinBernstorff/lumberman/commit/466246653124cdc31462c97b73eea22eba43dc9b))

* perf: no-need-to-sync-before-submit ([`719cdab`](https://github.com/MartinBernstorff/lumberman/commit/719cdab6a18a2107bf29b29ff2885e7807d29886))

* perf: no-need-to-sync-before-submit ([`9426927`](https://github.com/MartinBernstorff/lumberman/commit/94269272c38f0e20bdd081b5cbc40c43d4251101))

### Style

* style: lint ([`568cf53`](https://github.com/MartinBernstorff/lumberman/commit/568cf536d24678597619ee4d6e60ff71508b1838))


## v0.13.0 (2024-01-09)

### Feature

* feat: support new prefix (issue #83) (#85)

feat: support new prefix (issue #83)

Fixes #83

misc.

misc.

misc.

misc. ([`963e7a3`](https://github.com/MartinBernstorff/lumberman/commit/963e7a3a9619cfa175fc286917536f475b46cf23))

* feat: submit descendants when running submit (issue #77) (#82)

feat: submit descendants when running submit (issue #77)

Fixes #77

misc. ([`7b16189`](https://github.com/MartinBernstorff/lumberman/commit/7b161891d843406f626fc47d3cb01b1fc5d0c62e))

* feat: submit descendants when running submit (issue #77)

Fixes #77 ([`40039a4`](https://github.com/MartinBernstorff/lumberman/commit/40039a4ad6acb6c50ee41165f966154264bbbf78))

* feat: restack on sync (issue #78) (#81)

feat: restack on sync (issue #78)

Fixes #78

feat: restack on sync (issue #78)

Fixes #78 ([`572c834`](https://github.com/MartinBernstorff/lumberman/commit/572c83466a1196db463c707bf5a51c0312a97b71))

* feat: restack on sync (issue #78)

Fixes #78 ([`f8f7815`](https://github.com/MartinBernstorff/lumberman/commit/f8f78152136ae44826737a9359d62ace7f9b9f06))

### Fix

* fix: typo ([`1d31e1b`](https://github.com/MartinBernstorff/lumberman/commit/1d31e1bea1923dd903a27a5834fd41807a5ee974))

### Unknown

* misc. ([`4983081`](https://github.com/MartinBernstorff/lumberman/commit/4983081c3c50a1c4324d5b48f422031aa3da68a5))

* misc. ([`8dabb1f`](https://github.com/MartinBernstorff/lumberman/commit/8dabb1fb56f203901cb09572e141652fb6dcbc7a))

* misc. ([`82e5000`](https://github.com/MartinBernstorff/lumberman/commit/82e5000c503cb313998e17dfea31f0fa1f268be7))

* misc. ([`2936338`](https://github.com/MartinBernstorff/lumberman/commit/29363383b33177d094a4cb55e1a55778cadae09a))

* misc. ([`6317036`](https://github.com/MartinBernstorff/lumberman/commit/631703656873e981827509ee3a6bb8f420317da2))

* misc. ([`302d7fe`](https://github.com/MartinBernstorff/lumberman/commit/302d7fe19db0e62e15326649617c9b9e04cf6709))

* misc. ([`4a03f96`](https://github.com/MartinBernstorff/lumberman/commit/4a03f96dbaebafaa5f30b6e846d27f840f602cca))


## v0.12.1 (2024-01-09)

### Fix

* fix: new should create branch from trunk (#80) ([`dcbb496`](https://github.com/MartinBernstorff/lumberman/commit/dcbb496b6383081ecf835a6ed925569377e88b58))

* fix: decrease syncs ([`1a3d21b`](https://github.com/MartinBernstorff/lumberman/commit/1a3d21ba81decee7e4c0dd3c2a2711e75bb7cc09))

* fix: new should create branch from trunk (issue #79)

Fixes #79 ([`50dfa29`](https://github.com/MartinBernstorff/lumberman/commit/50dfa29ab7e11a5cc358dd89651c53cf07d1502f))

### Unknown

* misc. ([`a18907f`](https://github.com/MartinBernstorff/lumberman/commit/a18907f62761a6c87da68ca040e7b451171d1e88))

* misc. ([`6f3e21e`](https://github.com/MartinBernstorff/lumberman/commit/6f3e21e525c6da81f386fec114f14858e72dd5a9))

* misc. ([`2b77a63`](https://github.com/MartinBernstorff/lumberman/commit/2b77a63cd5f272ef387f37454a9a4705bbaceee5))

* misc. ([`94ae390`](https://github.com/MartinBernstorff/lumberman/commit/94ae3904558e2149dc351456bf2cdb475b8911ea))


## v0.12.0 (2024-01-09)

### Feature

* feat: show current stack state after each operation (issue #67) (#76) ([`3ea5b4c`](https://github.com/MartinBernstorff/lumberman/commit/3ea5b4c86662ed8b0a5659ec34cd63660c7b7dbf))


## v0.11.0 (2024-01-09)

### Feature

* feat: show current stack state after each operation (issue #67)

Fixes #67 ([`12292f2`](https://github.com/MartinBernstorff/lumberman/commit/12292f2f65cb87e6b175824b533bd845bea91d46))

* feat: show current stack state after each operation (issue #67)

Fixes #67 ([`541feef`](https://github.com/MartinBernstorff/lumberman/commit/541feef2fa06d795951875bacd2f61384b004cc1))

* feat: add herb status command (issue #69) (#75)

feat: add herb status command (issue #69)

Fixes #69

misc. ([`17d1719`](https://github.com/MartinBernstorff/lumberman/commit/17d17194c925822f494c171ae1592177c34e7071))


## v0.10.1 (2024-01-09)

### Feature

* feat: add herb status command (issue #69)

Fixes #69 ([`a4f6bc3`](https://github.com/MartinBernstorff/lumberman/commit/a4f6bc3462fbcd5be5efaf6d1278ca3c1017c1e4))

### Fix

* fix: remove  from descriptions since they have special meaning in shell (issue #70) (#74)

fix: remove  from descriptions since they have special meaning in shell (issue #70)

Fixes #70

misc. ([`9947474`](https://github.com/MartinBernstorff/lumberman/commit/9947474bafb794fb2d28870f0138f292c1084e9f))

* fix: remove  from descriptions since they have special meaning in shell (issue #70)

Fixes #70 ([`d555127`](https://github.com/MartinBernstorff/lumberman/commit/d5551278d9dea79eba7bf27ce4012ae9f15819fb))

* fix: insert-at-front (issue #68) (#73)

fix: insert-at-front (issue #68)

Fixes #68

misc. ([`1b612be`](https://github.com/MartinBernstorff/lumberman/commit/1b612beca91156d42f20a60eff21f8d432ea7222))

* fix: insert-at-front (issue #68)

Fixes #68 ([`f8488e2`](https://github.com/MartinBernstorff/lumberman/commit/f8488e22797253a5fe8797d2181d537371435938))

### Unknown

* misc. ([`9cbd95c`](https://github.com/MartinBernstorff/lumberman/commit/9cbd95cea209bb99c9581c3cde83a6159474825e))

* misc. ([`13d7208`](https://github.com/MartinBernstorff/lumberman/commit/13d72086969505b1daa392f2a5b26b498ee4d65d))

* misc. ([`c3aa3ad`](https://github.com/MartinBernstorff/lumberman/commit/c3aa3ad9f71a946e8b8f9abb4621273bdef75e4e))

* cli: fix emoji handling in prompt (#58) (#66)

Fixes #58 ([`9c9b8ad`](https://github.com/MartinBernstorff/lumberman/commit/9c9b8adc0f96105a7f7a85cb9d4a940f550e9c28))


## v0.10.0 (2024-01-09)

### Feature

* feat: add issue number to PR title (#65)

feat: add issue number to PR title

feat: add issue number to PR title ([`d3c0437`](https://github.com/MartinBernstorff/lumberman/commit/d3c043795aeb4c3b608a18fe4e69f9fa0292eaba))

* feat: add issue number to PR title ([`6e24ae6`](https://github.com/MartinBernstorff/lumberman/commit/6e24ae6d8671d5a41cf72635c639797075eaa75d))

* feat: add issue number to PR title ([`1800951`](https://github.com/MartinBernstorff/lumberman/commit/1800951e19699a1562a7817f84dfffba6592edda))

### Unknown

* cli: fix emoji handling in prompt (#58)

Fixes #58 ([`2e76529`](https://github.com/MartinBernstorff/lumberman/commit/2e7652948e36f62777f977c6c80678523a6bf911))

* misc. ([`e76cb20`](https://github.com/MartinBernstorff/lumberman/commit/e76cb20df4ea038ebdc31cf467e2140a6fbf1f65))


## v0.9.0 (2024-01-08)

### Feature

* feat: insert at bottom (#61)

feat: insert at bottom

Fixes #51

misc.

misc. ([`3cb9eda`](https://github.com/MartinBernstorff/lumberman/commit/3cb9eda640bc38b7fab4c1c06c96875e3b85cc08))


## v0.8.2 (2024-01-08)

### Feature

* feat: insert at bottom

Fixes #51 ([`fd42fcc`](https://github.com/MartinBernstorff/lumberman/commit/fd42fcc592a8ff2c12f60c93ef57cd07daa14b32))

### Fix

* fix: Fixes in first commit (#60)

fix: Fixes in first commit

fix: Fixes in first commit ([`e69d0d7`](https://github.com/MartinBernstorff/lumberman/commit/e69d0d77f91632bea76fc4adcb68a0921d8a6632))

* fix: Fixes in first commit ([`8341b40`](https://github.com/MartinBernstorff/lumberman/commit/8341b4002f4ce350952942c2cf19a29a90815f0c))

### Style

* style: linting ([`fe5571d`](https://github.com/MartinBernstorff/lumberman/commit/fe5571d1bf4843568062e57062ff5c4c1c09b8cc))

* style: lint ([`249025e`](https://github.com/MartinBernstorff/lumberman/commit/249025ea8555b34554a7ae3844e5a5db206c5ae6))

### Unknown

* misc. ([`5402933`](https://github.com/MartinBernstorff/lumberman/commit/5402933314d9691d87237f0493f8250765ebdcf5))

* misc. ([`f5a2a01`](https://github.com/MartinBernstorff/lumberman/commit/f5a2a0140dc51f86955be51d88a5a62728f6320f))

* misc. ([`87bc825`](https://github.com/MartinBernstorff/lumberman/commit/87bc825a7e31de6e38abfc4d16b4dfcfc80fe162))

* cli: fix emoji handling in prompt

Fixes #{issue.entity_id} ([`4b69473`](https://github.com/MartinBernstorff/lumberman/commit/4b694735d166b83f1cf9c551acf6394d5b77e7bd))

* dev: remove redundant ruff target version ([`ab5534a`](https://github.com/MartinBernstorff/lumberman/commit/ab5534a50a4e2c8a85435fa432daef0fc4047357))

* misc. ([`511cc27`](https://github.com/MartinBernstorff/lumberman/commit/511cc27048ea8cec7c0fa25a7ac1690d4721942a))

* misc. ([`fc57fee`](https://github.com/MartinBernstorff/lumberman/commit/fc57fee4096854fa11cbd1e8d66a417275bbf67f))

* misc. ([`be268a0`](https://github.com/MartinBernstorff/lumberman/commit/be268a0435c2f99d707f079544967adc4e1d02d5))

* cli: fix emoji handling in prompt

Fixes #{issue.entity_id} ([`edd4e74`](https://github.com/MartinBernstorff/lumberman/commit/edd4e74a34c8601b8997084a6d5127b7183fbb64))

* dev: remove redundant ruff target version ([`bf7f6a4`](https://github.com/MartinBernstorff/lumberman/commit/bf7f6a463d85aae7f3a2b1b1a1014c95f42984a2))

* cli: fix emoji handling in prompt (#59)

cli: fix emoji handling in prompt

Fixes #{issue.entity_id}

misc. ([`79392c0`](https://github.com/MartinBernstorff/lumberman/commit/79392c07ba9cb5187327a4513be7778c7e0f61f0))

* misc. ([`1ff09a2`](https://github.com/MartinBernstorff/lumberman/commit/1ff09a2aa12ef7f7e6ec7cfdb9409b10d1b5ac0a))

* dev: remove redundant ruff target version (#63)

dev: remove redundant ruff target version

dev: remove redundant ruff target version ([`3737c4a`](https://github.com/MartinBernstorff/lumberman/commit/3737c4a597e0cc1c40101bc588304d11ca38853b))

* dev: remove redundant ruff target version ([`3149656`](https://github.com/MartinBernstorff/lumberman/commit/31496564ce8afe8be1d3e679faa88bef4be0efb4))

* dev: remove redundant ruff target version ([`0acebcb`](https://github.com/MartinBernstorff/lumberman/commit/0acebcb24fc75f6bb6e5bf52e848fef2bac08c5a))


## v0.8.1 (2024-01-08)

### Fix

* fix: prettier subprocess handling (#57)

fix: prettier subprocess handling

Fixes #{issue.entity_id}

misc. ([`2faa5a2`](https://github.com/MartinBernstorff/lumberman/commit/2faa5a2fc05ca27116099a4761aa83eaf23e8bcf))

* fix: prettier subprocess handling

Fixes #{issue.entity_id} ([`5e4204e`](https://github.com/MartinBernstorff/lumberman/commit/5e4204eed04344cb8ae8db6a01f9fba6c1da0ec0))

### Unknown

* misc. ([`d2edd50`](https://github.com/MartinBernstorff/lumberman/commit/d2edd5065dc6a95ce66aa16292a2c21a52c78828))


## v0.8.0 (2024-01-08)

### Feature

* feat: simplify prompt (#56)

feat: simplify prompt

misc. ([`c017abd`](https://github.com/MartinBernstorff/lumberman/commit/c017abdd64406dc93ca283c3e2846cdc3dfc875d))

* feat: simplify prompt ([`92c1885`](https://github.com/MartinBernstorff/lumberman/commit/92c18850cddbe9d107f6759eed17b008e12cb17a))

### Unknown

* misc. ([`649fe4a`](https://github.com/MartinBernstorff/lumberman/commit/649fe4af6410923a945ba9855045d22b96c326e9))

* misc. (#55) ([`8c91f5c`](https://github.com/MartinBernstorff/lumberman/commit/8c91f5cc75573a84caa45e4e70b17606577d2158))

* misc. ([`f1656a7`](https://github.com/MartinBernstorff/lumberman/commit/f1656a7493273eb93fe867a546ecf599d8247a77))


## v0.7.0 (2024-01-08)

### Feature

* feat: allow manual creation (#53)

feat: allow manual creation

Fixes #20

misc.

misc.

misc.

misc.

misc.

misc. ([`aa7f404`](https://github.com/MartinBernstorff/lumberman/commit/aa7f404b2bbbd59965ea10f3ab92b0561bc83468))

* feat: allow manual creation

Fixes #20 ([`8050c4b`](https://github.com/MartinBernstorff/lumberman/commit/8050c4b7a10f29817dec260100b58f2a2c4a296c))

### Style

* style: linting ([`2f095e1`](https://github.com/MartinBernstorff/lumberman/commit/2f095e1cfb478ddcc9117b9814a034bfbba1bf43))

### Unknown

* misc. ([`ba0a034`](https://github.com/MartinBernstorff/lumberman/commit/ba0a034bfce09b875d3fbcfffa65e78f88113e97))

* misc. ([`d3c75fe`](https://github.com/MartinBernstorff/lumberman/commit/d3c75fec3ad59a2a160ca0f2236f6a943d1cae9f))

* misc. ([`4bccccb`](https://github.com/MartinBernstorff/lumberman/commit/4bccccbd3ba923d8e00c0465a4c8fd07d72a0312))

* misc. ([`13b5811`](https://github.com/MartinBernstorff/lumberman/commit/13b5811285d6e4d66e9574036c79fe14786861be))

* misc. ([`9dd20aa`](https://github.com/MartinBernstorff/lumberman/commit/9dd20aa8fb5909ecc7899ab17dc9b0841c59d163))

* misc. ([`88e8b32`](https://github.com/MartinBernstorff/lumberman/commit/88e8b32c4fecd0af366c87bef521c0d0b0ece832))

* misc. ([`345ec2f`](https://github.com/MartinBernstorff/lumberman/commit/345ec2fc3b379f2016097b48ceebb69976450d23))


## v0.6.0 (2024-01-08)

### Feature

* feat: cleaner issue title parsing (#48) ([`da985b9`](https://github.com/MartinBernstorff/lumberman/commit/da985b91103e8421ca653a448122936e8e0d05ea))

* feat: cleaner issue title parsing

Fixes #16 ([`76821cf`](https://github.com/MartinBernstorff/lumberman/commit/76821cfb833bf16e2f80df519b025a14b3d29304))

### Unknown

* cli: present refresh option when finding issues (#50) ([`3d69629`](https://github.com/MartinBernstorff/lumberman/commit/3d69629d79115793bc490bb4a95552aad238fafe))

* misc. ([`a4300f9`](https://github.com/MartinBernstorff/lumberman/commit/a4300f9d9779cfa9e7566850a32e65a33d737bbf))

* cli: present refresh option when finding issues

Fixes #49 ([`3a6f020`](https://github.com/MartinBernstorff/lumberman/commit/3a6f020c5e274b30e6e3a72dc54ae2cd6a5c3df7))

* misc. ([`a8b9623`](https://github.com/MartinBernstorff/lumberman/commit/a8b96233560dd2d4e92f6d860b221056a1dc507a))


## v0.5.0 (2024-01-08)

### Feature

* feat: pretty error message if no issues assigned (#47)

feat: pretty error message if no issues assigned

Fixes #29

misc.

fix: types ([`84f501e`](https://github.com/MartinBernstorff/lumberman/commit/84f501eb5f27788f546b96809d843b02be8fbaf0))

* feat: pretty error message if no issues assigned

Fixes #29 ([`6087659`](https://github.com/MartinBernstorff/lumberman/commit/608765985b3afb2c82fe85e26e7c07933637148e))

### Fix

* fix: types ([`50ef8e8`](https://github.com/MartinBernstorff/lumberman/commit/50ef8e8ea9465dfc270425921923fc15148f7aee))

### Unknown

* misc. ([`6c195ba`](https://github.com/MartinBernstorff/lumberman/commit/6c195ba50e21f5b9f55e937216b9be266c9ac699))


## v0.4.1 (2024-01-08)

### Ci

* ci: run tests on prs against any branch (#39) ([`e21f947`](https://github.com/MartinBernstorff/lumberman/commit/e21f9477d183d65fd1d7701e691d1c46882a15ef))

* ci: run tests on prs against any branch ([`28c6035`](https://github.com/MartinBernstorff/lumberman/commit/28c603591f7b3037a610a8261c67a14f449aab39))

### Fix

* fix: prettier log

Fixes #35 ([`8e149ba`](https://github.com/MartinBernstorff/lumberman/commit/8e149ba4aa166e439138f027894b41a909798fe2))

### Unknown

* cli: reverse log output (#45)

cli: reverse log output

Fixes #44

cli: reverse log output

Fixes #44 ([`a4faa4b`](https://github.com/MartinBernstorff/lumberman/commit/a4faa4ba49ef31d6e2dad7b95e275b32909b0f72))

* cli: reverse log output

Fixes #44 ([`3d68811`](https://github.com/MartinBernstorff/lumberman/commit/3d6881183f9af53a875e67c9a2521fb9c960b58a))

* misc. ([`5213f14`](https://github.com/MartinBernstorff/lumberman/commit/5213f1453aa956db3bc17f349bdcda8c5b2d22c6))

* misc. ([`428c6ae`](https://github.com/MartinBernstorff/lumberman/commit/428c6aeeb101c1554f5515278829564ad2e73883))

* cli: simplify stack submit animations (#43)

cli: simplify stack submit animations

Fixes #42

misc. ([`d2e44b6`](https://github.com/MartinBernstorff/lumberman/commit/d2e44b60dbe2b96a5c4a7b56d3b0022c321de8a5))

* misc. ([`834beb9`](https://github.com/MartinBernstorff/lumberman/commit/834beb96486e0aee8efabe881543cc462af9db4f))

* dev: submit with automerge (#41)

dev: submit with automerge

Fixes #40

misc. ([`1657a46`](https://github.com/MartinBernstorff/lumberman/commit/1657a46d5e56d4855554458010c1da773e026451))

* misc. ([`0b43842`](https://github.com/MartinBernstorff/lumberman/commit/0b43842cf145ba29421fd2521cf8cc24b23ef326))

* dev: submit with automerge

Fixes #40 ([`144e52c`](https://github.com/MartinBernstorff/lumberman/commit/144e52ca324fc353070af6f2926fc74d7eb1e848))


## v0.4.0 (2024-01-08)

### Feature

* feat: delete unused branches on submit (#37)

feat: delete unused branches on submit

Fixes #30

misc.

fix: even prettier logs ([`45d6a50`](https://github.com/MartinBernstorff/lumberman/commit/45d6a50f0d7238790d0b657594987c1b678c648d))


## v0.3.1 (2024-01-08)

### Fix

* fix: prettier log (#36)

fix: prettier log

Fixes #35

fix: prettier log

Fixes #35 ([`4482f2c`](https://github.com/MartinBernstorff/lumberman/commit/4482f2c9dda485cc006ab5b299f412525a1eabc5))


## v0.3.0 (2024-01-08)

### Feature

* feat: newline after submitting stack to get log pretty (#34)

feat: newline after submitting stack to get log pretty

Fixes #31

misc. ([`99de3de`](https://github.com/MartinBernstorff/lumberman/commit/99de3ded14a272fe85e2e2a68a0e7ce555305a3f))

* feat: make automerge a command-line argument (#33)

Fixes #32 ([`6ecac7f`](https://github.com/MartinBernstorff/lumberman/commit/6ecac7f1ae9a2829d2696b0af8e226997e476ecc))


## v0.2.0 (2024-01-08)

### Feature

* feat: support python &gt;=3.9 (#28)

feat: support python &gt;=3.9

Fixes #27

feat: support python &gt;=3.9

Fixes #27

misc.

misc.

misc. ([`61d9402`](https://github.com/MartinBernstorff/lumberman/commit/61d9402f6601fbe85c6a6c2bec04d6211a4f8007))


## v0.1.0 (2024-01-07)

### Ci

* ci: fix release pipeline ([`e28c77c`](https://github.com/MartinBernstorff/lumberman/commit/e28c77ca98d35733ae3309265bc8d73d6ca9afe5))

* ci: setup release to pypi (#24)

ci: setup release to pypi

Fixes #21

ci: setup release to pypi

Fixes #21

tests: get tests running

misc.

ci: setup release.yml ([`3106412`](https://github.com/MartinBernstorff/lumberman/commit/3106412b885c832f12feaa75c1dc5d16c0088292))

### Feature

* feat: add GithubIssueService

Fixes #8. ([`c2939c3`](https://github.com/MartinBernstorff/lumberman/commit/c2939c3e12247e255293837076643fd6ae811451))

### Unknown

* misc. ([`79f4f2d`](https://github.com/MartinBernstorff/lumberman/commit/79f4f2df5ae0960c0ef15fb96f18ea30eb1eafc5))

* misc. ([`3ad9517`](https://github.com/MartinBernstorff/lumberman/commit/3ad95172a8addfe265cca73cef58c9ee69e5eae2))

* dev: create github cli dir on devcontainer init ([`58c40e6`](https://github.com/MartinBernstorff/lumberman/commit/58c40e6f34e14a1192a6ff177a53f5f417825ab8))

* misc. ([`8de39ac`](https://github.com/MartinBernstorff/lumberman/commit/8de39ac6cb6d45ab0c7066fa18553a4b7a2bade3))

* $feat: pretty cli animations with typer/rich (#23)

$feat: pretty cli animations with typer/rich

Fixes #13

$feat: pretty cli animations with typer/rich

Fixes #13

misc.

misc. ([`830040c`](https://github.com/MartinBernstorff/lumberman/commit/830040c8ec929215791ec495332ebefcc1eca7bd))

* dev: clean up gitignore (#22)

Fixes #19 ([`a58c808`](https://github.com/MartinBernstorff/lumberman/commit/a58c808497b99ee460ad38e840ed658a1a2d93f9))

* $fix: misc. types (#17)

$fix: misc. types

Fixes #14

$fix: misc. types

Fixes #14

refactor: cleanup

misc. ([`4342005`](https://github.com/MartinBernstorff/lumberman/commit/43420050f810d0bad2e6b85708d6d4449140e1c4))

* misc. ([`9d6b6de`](https://github.com/MartinBernstorff/lumberman/commit/9d6b6ded5bd4a56f0fa2f4731c65ef02d4e32ad1))

* Update README.md (#12) ([`f2d76a0`](https://github.com/MartinBernstorff/lumberman/commit/f2d76a05372650b192b47205bca60a3803549762))

* first commit ([`5af600e`](https://github.com/MartinBernstorff/lumberman/commit/5af600e2b31b082b6785271c806243553de5e7bf))
